==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Widgets/StatusBar/ts/StatusBar_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>StatusBar</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+47"/>
        <source>Status Bar Font:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Font Status Bar:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Status Bar Widgets</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Coordinate display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Mouse display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Selection display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Progress display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../StatusBar.js" line="+32"/>
        <source>Widgets</source>
        <translatorcomment>--exact match--
--file: designer_pl.ts--
Własne widżety
Zastępcze widżety</translatorcomment>
        <translation type="unfinished">Widżety</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Status Bar</source>
        <translatorcomment>--google--
Utwórz pasek stanu
Usuń pasek stanu</translatorcomment>
        <translation type="unfinished">Status Bar</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Status Bar</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Widgets/StatusBar/ts/StatusBar_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>StatusBar</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+53"/>
        <source>Status Bar Font:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Czcionka paska stanu:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Status Bar Widgets</source>
        <translation>Widżety paska stanu</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Coordinate display</source>
        <translation>Współrzędne</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Mouse display</source>
        <translation>Mysz</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Selection display</source>
        <translation>Zaznaczenie</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Progress display</source>
        <translation>Postęp</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Show status tips</source>
        <translation>Podpowiedzi stanu</translation>
    </message>
    <message>
        <location filename="../StatusBar.js" line="+32"/>
        <source>Widgets</source>
        <translatorcomment>--exact match--
--file: designer_pl.ts--
Własne widżety
Zastępcze widżety</translatorcomment>
        <translation>Widżety</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Status Bar</source>
        <translatorcomment>--google--
Utwórz pasek stanu
Usuń pasek stanu</translatorcomment>
        <translation>Pasek stanu</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Status Bar</source>
        <translation>Pasek &amp;stanu</translation>
    </message>
</context>
</TS>
